@@ -6,7 +6,6 @@
  * See LICENSE for the license.
  *
  */
-
 #include <config.h>
 
 #include <assert.h>
@@ -22,6 +21,8 @@
 #ifndef HAVE_PSELECT
 int pselect(int n, fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
 	    const struct timespec *timeout, const sigset_t *sigmask);
+#else
+#include <sys/select.h>
 #endif
 
 
@@ -42,6 +43,7 @@ netio_create(region_type *region)
 	result->region = region;
 	result->handlers = NULL;
 	result->deallocated = NULL;
+	result->dispatch_next = NULL;
 	return result;
 }
 
@@ -84,6 +86,8 @@ netio_remove_handler(netio_type *netio, netio_handler_type *handler)
 	for (elt_ptr = &netio->handlers; *elt_ptr; elt_ptr = &(*elt_ptr)->next) {
 		if ((*elt_ptr)->handler == handler) {
 			netio_handler_list_type *next = (*elt_ptr)->next;
+			if ((*elt_ptr) == netio->dispatch_next)
+				netio->dispatch_next = next;
 			(*elt_ptr)->handler = NULL;
 			(*elt_ptr)->next = netio->deallocated;
 			netio->deallocated = *elt_ptr;
@@ -149,7 +153,7 @@ netio_dispatch(netio_type *netio, const struct timespec *timeout, const sigset_t
 
 	for (elt = netio->handlers; elt; elt = elt->next) {
 		netio_handler_type *handler = elt->handler;
-		if (handler->fd >= 0) {
+		if (handler->fd >= 0 && handler->fd < (int)FD_SETSIZE) {
 			if (handler->fd > max_fd) {
 				max_fd = handler->fd;
 			}
@@ -198,6 +202,11 @@ netio_dispatch(netio_type *netio, const struct timespec *timeout, const sigset_t
 		     have_timeout ? &minimum_timeout : NULL,
 		     sigmask);
 	if (rc == -1) {
+		if(errno == EINVAL || errno == EACCES || errno == EBADF) {
+			log_msg(LOG_ERR, "fatal error pselect: %s.", 
+				strerror(errno));
+			exit(1);
+		}
 		return -1;
 	}
 
@@ -222,29 +231,37 @@ netio_dispatch(netio_type *netio, const struct timespec *timeout, const sigset_t
 		 * deinstall itself, so store the next handler before
 		 * calling the current handler!
 		 */
-		for (elt = netio->handlers; elt; ) {
-			netio_handler_list_type *next = elt->next;
+		assert(netio->dispatch_next == NULL);
+		for (elt = netio->handlers; elt && rc; ) {
 			netio_handler_type *handler = elt->handler;
-			if (handler->fd >= 0) {
+			netio->dispatch_next = elt->next;
+			if (handler->fd >= 0 && handler->fd < (int)FD_SETSIZE) {
 				netio_event_types_type event_types
 					= NETIO_EVENT_NONE;
 				if (FD_ISSET(handler->fd, &readfds)) {
 					event_types |= NETIO_EVENT_READ;
+					FD_CLR(handler->fd, &readfds);
+					rc--;
 				}
 				if (FD_ISSET(handler->fd, &writefds)) {
 					event_types |= NETIO_EVENT_WRITE;
+					FD_CLR(handler->fd, &writefds);
+					rc--;
 				}
 				if (FD_ISSET(handler->fd, &exceptfds)) {
 					event_types |= NETIO_EVENT_EXCEPT;
+					FD_CLR(handler->fd, &exceptfds);
+					rc--;
 				}
 
-				if (event_types) {
-					handler->event_handler(netio, handler, event_types);
+				if (event_types & handler->event_types) {
+					handler->event_handler(netio, handler, event_types & handler->event_types);
 					++result;
 				}
 			}
-			elt = next;
+			elt = netio->dispatch_next;
 		}
+		netio->dispatch_next = NULL;
 	}
 
 	return result;
