@@ -370,7 +370,7 @@ main (int argc, char *argv[])
 
 	/* Parse the command line... */
 	while ((c = getopt(argc, argv, "46a:c:df:hi:I:l:N:n:P:p:s:u:t:X:V:v"
-#ifndef NDEBUG	
+#ifndef NDEBUG
 		"F:L:"
 #endif /* NDEBUG */
 		)) != -1) {
@@ -555,7 +555,7 @@ main (int argc, char *argv[])
 		if(nsd.options->pidfile) nsd.pidfile = nsd.options->pidfile;
 		else nsd.pidfile = PIDFILE;
 	}
-	if(nsd.identity == hostname || nsd.identity == IDENTITY)
+	if(strcmp(nsd.identity, hostname)==0 || strcmp(nsd.identity,IDENTITY)==0)
 	{
 		if(nsd.options->identity) nsd.identity = nsd.options->identity;
 	}
@@ -785,7 +785,7 @@ main (int argc, char *argv[])
 	/* Unless we're debugging, fork... */
 	if (!nsd.debug) {
 		int fd;
-		
+
 		/* Take off... */
 		switch ((nsd.pid = fork())) {
 		case 0:
