@@ -320,7 +320,7 @@ int compare_serial(uint32_t a, uint32_t b);
  */
 void cleanup_region(void *data);
 
-/* 
+/*
  * Region used to store owner and origin of previous RR (used
  * for pretty printing of zone data).
  * Keep the same between calls to print_rr.
@@ -339,7 +339,7 @@ int print_rr(FILE *out, struct state_pretty_rr* state, struct rr *record);
  */
 const char* rcode2str(int rc);
 
-/* 
+/*
  * Stack of pointers.
  * Stack is fixed size on start. More elems fall off stack.
  */
@@ -351,5 +351,12 @@ typedef struct stack stack_type;
 stack_type* stack_create(struct region* region, size_t size);
 void stack_push(stack_type* stack, void* elem);
 void* stack_pop(stack_type* stack);
+int addr2ip(
+#ifdef INET6
+	struct sockaddr_storage addr
+#else
+	struct sockaddr_in addr
+#endif
+, char address[], socklen_t size);
 
 #endif /* _UTIL_H_ */
